autoplot.tbl_cf: Auto- and Cross- Covariance and -Correlation plots
Description
Produces an appropriate plot for the result of feasts::ACF(), feasts::PACF(), or feasts::CCF().
Usage
# S3 method for tbl_cf
autoplot(object, level = 95, ...)
Value
A ggplot object showing the correlations.
Arguments
- object
A tbl_cf object (the result feasts::ACF(), feasts::PACF(), or feasts::CCF()).
- level
The level of confidence for the blue dashed lines.
- ...
Unused.